==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebRangeSliderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRangeSliderValueEventArgsDescriptionMetadata } from "./WebRangeSliderValueEventArgsDescriptionMetadata";
import { WebSliderBaseDescriptionMetadata } from "./WebSliderBaseDescriptionMetadata";
import { WebRangeSliderDescription } from "./WebRangeSliderDescription";
/**
 * @hidden
 */
var WebRangeSliderDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebRangeSliderDescriptionMetadata, _super);
    function WebRangeSliderDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRangeSliderDescriptionMetadata.b = function (a) {
        if (WebRangeSliderDescriptionMetadata.a == null) {
            WebRangeSliderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRangeSliderDescriptionMetadata.c(WebRangeSliderDescriptionMetadata.a);
        }
        if (a.k(WebRangeSliderDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebRangeSliderDescriptionMetadata.a);
        WebRangeSliderValueEventArgsDescriptionMetadata.d(a);
    };
    WebRangeSliderDescriptionMetadata.c = function (a) {
        WebSliderBaseDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:RangeSlider");
        a.item("__tagNameWC", "String:igc-range-slider");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Lower", "Number:double");
        a.item("Upper", "Number:double");
        a.item("AriaLabelLower", "String");
        a.item("AriaLabelUpper", "String");
        a.item("InputRef", "EventRef::input");
        a.item("ChangeRef", "EventRef::change");
    };
    WebRangeSliderDescriptionMetadata.d = function (a) {
        WebRangeSliderDescriptionMetadata.b(a);
        a.ac("WebRangeSlider", function () { return new WebRangeSliderDescription(); });
        a.ab("WebRangeSlider", WebRangeSliderDescriptionMetadata.a);
    };
    WebRangeSliderDescriptionMetadata.$t = markType(WebRangeSliderDescriptionMetadata, 'WebRangeSliderDescriptionMetadata');
    WebRangeSliderDescriptionMetadata.a = null;
    return WebRangeSliderDescriptionMetadata;
}(Base));
export { WebRangeSliderDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebRangeSliderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRangeSliderValueEventArgsDescriptionMetadata } from "./WebRangeSliderValueEventArgsDescriptionMetadata";
import { WebSliderBaseDescriptionMetadata } from "./WebSliderBaseDescriptionMetadata";
import { WebRangeSliderDescription } from "./WebRangeSliderDescription";
/**
 * @hidden
 */
var WebRangeSliderDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebRangeSliderDescriptionMetadata, _super);
    function WebRangeSliderDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebRangeSliderDescriptionMetadata.b = function (a) {
        if (WebRangeSliderDescriptionMetadata.a == null) {
            WebRangeSliderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebRangeSliderDescriptionMetadata.c(WebRangeSliderDescriptionMetadata.a);
        }
        if (a.k(WebRangeSliderDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebRangeSliderDescriptionMetadata.a);
        WebRangeSliderValueEventArgsDescriptionMetadata.d(a);
    };
    WebRangeSliderDescriptionMetadata.c = function (a) {
        WebSliderBaseDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:RangeSlider");
        a.item("__tagNameWC", "String:igc-range-slider");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Lower", "Number:double");
        a.item("Upper", "Number:double");
        a.item("ThumbLabelLower", "String");
        a.item("ThumbLabelUpper", "String");
        a.item("InputRef", "EventRef::input");
        a.item("ChangeRef", "EventRef::change");
    };
    WebRangeSliderDescriptionMetadata.d = function (a) {
        WebRangeSliderDescriptionMetadata.b(a);
        a.ae("WebRangeSlider", function () { return new WebRangeSliderDescription(); });
        a.ad("WebRangeSlider", WebRangeSliderDescriptionMetadata.a);
    };
    WebRangeSliderDescriptionMetadata.$t = markType(WebRangeSliderDescriptionMetadata, 'WebRangeSliderDescriptionMetadata');
    WebRangeSliderDescriptionMetadata.a = null;
    return WebRangeSliderDescriptionMetadata;
}(Base));
export { WebRangeSliderDescriptionMetadata };
